@@ -19,9 +19,9 @@ class MyForm(QtGui.QMainWindow):
                 QtCore.QObject.connect(self.ui.pushButton, QtCore.SIGNAL('clicked()'), self.playFart)
                 
                 self.farts={
-                        "Kaos":"kaos.wav", "Polisen":"polisen.wav",
-                        "Ta Han":"tahan.wav", "Tung":"klippa.wav",
-                        "Bilen":"bilen.wav",
+                        "Kaos":"/opt/Laserturken/kaos.wav", "Polisen":"/opt/Laserturken/polisen.wav",
+                        "Ta Han":"/opt/Laserturken/tahan.wav", "Tung":"/opt/Laserturken/klippa.wav",
+                        "Bilen":"/opt/Laserturken/bilen.wav",
                         }
                 
         def playFart(self):
